voice_name_to_language_code = {
    'af-ZA-AdriNeural': 'af-ZA',  # Afrikaans (South Africa), Female
    'af-ZA-WillemNeural': 'af-ZA',  # Afrikaans (South Africa), Male
    'am-ET-MekdesNeural': 'am-ET',  # Amharic (Ethiopia), Female
    'am-ET-AmehaNeural': 'am-ET',  # Amharic (Ethiopia), Male
    'ar-DZ-AminaNeural': 'ar-DZ',  # Arabic (Algeria), Female
    'ar-DZ-IsmaelNeural': 'ar-DZ',  # Arabic (Algeria), Male
    'ar-BH-LailaNeural': 'ar-BH',  # Arabic (Bahrain), Female
    'ar-BH-AliNeural': 'ar-BH',  # Arabic (Bahrain), Male
    'ar-EG-SalmaNeural': 'ar-EG',  # Arabic (Egypt), Female
    'ar-EG-ShakirNeural': 'ar-EG',  # Arabic (Egypt), Male
    'ar-IQ-RanaNeural': 'ar-IQ',  # Arabic (Iraq), Female
    'ar-IQ-BasselNeural': 'ar-IQ',  # Arabic (Iraq), Male
    'ar-JO-SanaNeural': 'ar-JO',  # Arabic (Jordan), Female
    'ar-JO-TaimNeural': 'ar-JO',  # Arabic (Jordan), Male
    'ar-KW-NouraNeural': 'ar-KW',  # Arabic (Kuwait), Female
    'ar-KW-FahedNeural': 'ar-KW',  # Arabic (Kuwait), Male
    'ar-LY-ImanNeural': 'ar-LY',  # Arabic (Libya), Female
    'ar-LY-OmarNeural': 'ar-LY',  # Arabic (Libya), Male
    'ar-MA-MounaNeural': 'ar-MA',  # Arabic (Morocco), Female
    'ar-MA-JamalNeural': 'ar-MA',  # Arabic (Morocco), Male
    'ar-QA-AmalNeural': 'ar-QA',  # Arabic (Qatar), Female
    'ar-QA-MoazNeural': 'ar-QA',  # Arabic (Qatar), Male
    'ar-SA-ZariyahNeural': 'ar-SA',  # Arabic (Saudi Arabia), Female
    'ar-SA-HamedNeural': 'ar-SA',  # Arabic (Saudi Arabia), Male
    'ar-SY-AmanyNeural': 'ar-SY',  # Arabic (Syria), Female
    'ar-SY-LaithNeural': 'ar-SY',  # Arabic (Syria), Male
    'ar-TN-ReemNeural': 'ar-TN',  # Arabic (Tunisia), Female
    'ar-TN-HediNeural': 'ar-TN',  # Arabic (Tunisia), Male
    'ar-AE-FatimaNeural': 'ar-AE',  # Arabic (United Arab Emirates), Female
    'ar-AE-HamdanNeural': 'ar-AE',  # Arabic (United Arab Emirates), Male
    'ar-YE-MaryamNeural': 'ar-YE',  # Arabic (Yemen), Female
    'ar-YE-SalehNeural': 'ar-YE',  # Arabic (Yemen), Male
    'bn-BD-NabanitaNeural': 'bn-BD',  # Bangla (Bangladesh), Female
    'bn-BD-PradeepNeural': 'bn-BD',  # Bangla (Bangladesh), Male
    'bg-BG-KalinaNeural': 'bg-BG',  # Bulgarian (Bulgaria), Female
    'bg-BG-BorislavNeural': 'bg-BG',  # Bulgarian (Bulgaria), Male
    'my-MM-NilarNeural': 'my-MM',  # Burmese (Myanmar), Female
    'my-MM-ThihaNeural': 'my-MM',  # Burmese (Myanmar), Male
    'ca-ES-AlbaNeural': 'ca-ES',  # Catalan (Spain), Female
    'ca-ES-JoanaNeural': 'ca-ES',  # Catalan (Spain), Female
    'ca-ES-EnricNeural': 'ca-ES',  # Catalan (Spain), Male
    'zh-HK-HiuGaaiNeural': 'zh-HK',  # Chinese (Cantonese, Traditional), Female
    'zh-HK-HiuMaanNeural': 'zh-HK',  # Chinese (Cantonese, Traditional), Female
    'zh-HK-WanLungNeural': 'zh-HK',  # Chinese (Cantonese, Traditional), Male
    'zh-CN-XiaohanNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Female
    'zh-CN-XiaomoNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Female
    'zh-CN-XiaoruiNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Female
    'zh-CN-XiaoxiaoNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Female
    'zh-CN-XiaoxuanNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Female
    'zh-CN-XiaoyouNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Female
    'zh-CN-YunxiNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Male
    'zh-CN-YunyangNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Male
    'zh-CN-YunyeNeural': 'zh-CN',  # Chinese (Mandarin, Simplified), Male
    'zh-TW-HsiaoChenNeural': 'zh-TW',  # Chinese (Taiwanese Mandarin), Female
    'zh-TW-HsiaoYuNeural': 'zh-TW',  # Chinese (Taiwanese Mandarin), Female
    'zh-TW-YunJheNeural': 'zh-TW',  # Chinese (Taiwanese Mandarin), Male
    'hr-HR-GabrijelaNeural': 'hr-HR',  # Croatian (Croatia), Female
    'hr-HR-SreckoNeural': 'hr-HR',  # Croatian (Croatia), Male
    'cs-CZ-VlastaNeural': 'cs-CZ',  # Czech (Czech), Female
    'cs-CZ-AntoninNeural': 'cs-CZ',  # Czech (Czech), Male
    'da-DK-ChristelNeural': 'da-DK',  # Danish (Denmark), Female
    'da-DK-JeppeNeural': 'da-DK',  # Danish (Denmark), Male
    'nl-BE-DenaNeural': 'nl-BE',  # Dutch (Belgium), Female
    'nl-BE-ArnaudNeural': 'nl-BE',  # Dutch (Belgium), Male
    'nl-NL-ColetteNeural': 'nl-NL',  # Dutch (Netherlands), Female
    'nl-NL-FennaNeural': 'nl-NL',  # Dutch (Netherlands), Female
    'nl-NL-MaartenNeural': 'nl-NL',  # Dutch (Netherlands), Male
    'en-AU-NatashaNeural': 'en-AU',  # English (Australia), Female
    'en-AU-WilliamNeural': 'en-AU',  # English (Australia), Male
    'en-CA-ClaraNeural': 'en-CA',  # English (Canada), Female
    'en-CA-LiamNeural': 'en-CA',  # English (Canada), Male
    'en-HK-YanNeural': 'en-HK',  # English (Hongkong), Female
    'en-HK-SamNeural': 'en-HK',  # English (Hongkong), Male
    'en-IN-NeerjaNeural': 'en-IN',  # English (India), Female
    'en-IN-PrabhatNeural': 'en-IN',  # English (India), Male
    'en-IE-EmilyNeural': 'en-IE',  # English (Ireland), Female
    'en-IE-ConnorNeural': 'en-IE',  # English (Ireland), Male
    'en-KE-AsiliaNeural': 'en-KE',  # English (Kenya), Female
    'en-KE-ChilembaNeural': 'en-KE',  # English (Kenya), Male
    'en-NZ-MollyNeural': 'en-NZ',  # English (New Zealand), Female
    'en-NZ-MitchellNeural': 'en-NZ',  # English (New Zealand), Male
    'en-NG-EzinneNeural': 'en-NG',  # English (Nigeria), Female
    'en-NG-AbeoNeural': 'en-NG',  # English (Nigeria), Male
    'en-PH-RosaNeural': 'en-PH',  # English (Philippines), Female
    'en-PH-JamesNeural': 'en-PH',  # English (Philippines), Male
    'en-SG-LunaNeural': 'en-SG',  # English (Singapore), Female
    'en-SG-WayneNeural': 'en-SG',  # English (Singapore), Male
    'en-ZA-LeahNeural': 'en-ZA',  # English (South Africa), Female
    'en-ZA-LukeNeural': 'en-ZA',  # English (South Africa), Male
    'en-TZ-ImaniNeural': 'en-TZ',  # English (Tanzania), Female
    'en-TZ-ElimuNeural': 'en-TZ',  # English (Tanzania), Male
    'en-GB-LibbyNeural': 'en-GB',  # English (United Kingdom), Female
    'en-GB-SoniaNeural': 'en-GB',  # English (United Kingdom), Female
    'en-GB-MiaNeural': 'en-GB',  # English (United Kingdom), Female
    'en-GB-RyanNeural': 'en-GB',  # English (United Kingdom), Male
    'en-US-AmberNeural': 'en-US',  # English (United States), Female
    'en-US-AriaNeural': 'en-US',  # English (United States), Female
    'en-US-AshleyNeural': 'en-US',  # English (United States), Female
    'en-US-CoraNeural': 'en-US',  # English (United States), Female
    'en-US-ElizabethNeural': 'en-US',  # English (United States), Female
    'en-US-JennyNeural': 'en-US',  # English (United States), Female
    'en-US-MichelleNeural': 'en-US',  # English (United States), Female
    'en-US-MonicaNeural': 'en-US',  # English (United States), Female
    'en-US-SaraNeural': 'en-US',  # English (United States), Female
    'en-US-AnaNeural': 'en-US',  # English (United States), Kid
    'en-US-BrandonNeural': 'en-US',  # English (United States), Male
    'en-US-ChristopherNeural': 'en-US',  # English (United States), Male
    'en-US-EricNeural': 'en-US',  # English (United States), Male
    'en-US-GuyNeural': 'en-US',  # English (United States), Male
    'en-US-JacobNeural': 'en-US',  # English (United States), Male
    'et-EE-AnuNeural': 'et-EE',  # Estonian (Estonia), Female
    'et-EE-KertNeural': 'et-EE',  # Estonian (Estonia), Male
    'fil-PH-BlessicaNeural': 'fil-PH',  # Filipino (Philippines), Female
    'fil-PH-AngeloNeural': 'fil-PH',  # Filipino (Philippines), Male
    'fi-FI-NooraNeural': 'fi-FI',  # Finnish (Finland), Female
    'fi-FI-SelmaNeural': 'fi-FI',  # Finnish (Finland), Female
    'fi-FI-HarriNeural': 'fi-FI',  # Finnish (Finland), Male
    'fr-BE-CharlineNeural': 'fr-BE',  # French (Belgium), Female
    'fr-BE-GerardNeural': 'fr-BE',  # French (Belgium), Male
    'fr-CA-SylvieNeural': 'fr-CA',  # French (Canada), Female
    'fr-CA-AntoineNeural': 'fr-CA',  # French (Canada), Male
    'fr-CA-JeanNeural': 'fr-CA',  # French (Canada), Male
    'fr-FR-DeniseNeural': 'fr-FR',  # French (France), Female
    'fr-FR-HenriNeural': 'fr-FR',  # French (France), Male
    'fr-CH-ArianeNeural': 'fr-CH',  # French (Switzerland), Female
    'fr-CH-FabriceNeural': 'fr-CH',  # French (Switzerland), Male
    'gl-ES-SabelaNeural': 'gl-ES',  # Galician (Spain), Female
    'gl-ES-RoiNeural': 'gl-ES',  # Galician (Spain), Male
    'de-AT-IngridNeural': 'de-AT',  # German (Austria), Female
    'de-AT-JonasNeural': 'de-AT',  # German (Austria), Male
    'de-DE-KatjaNeural': 'de-DE',  # German (Germany), Female
    'de-DE-ConradNeural': 'de-DE',  # German (Germany), Male
    'de-CH-LeniNeural': 'de-CH',  # German (Switzerland), Female
    'de-CH-JanNeural': 'de-CH',  # German (Switzerland), Male
    'el-GR-AthinaNeural': 'el-GR',  # Greek (Greece), Female
    'el-GR-NestorasNeural': 'el-GR',  # Greek (Greece), Male
    'gu-IN-DhwaniNeural': 'gu-IN',  # Gujarati (India), Female
    'gu-IN-NiranjanNeural': 'gu-IN',  # Gujarati (India), Male
    'he-IL-HilaNeural': 'he-IL',  # Hebrew (Israel), Female
    'he-IL-AvriNeural': 'he-IL',  # Hebrew (Israel), Male
    'hi-IN-SwaraNeural': 'hi-IN',  # Hindi (India), Female
    'hi-IN-MadhurNeural': 'hi-IN',  # Hindi (India), Male
    'hu-HU-NoemiNeural': 'hu-HU',  # Hungarian (Hungary), Female
    'hu-HU-TamasNeural': 'hu-HU',  # Hungarian (Hungary), Male
    'id-ID-GadisNeural': 'id-ID',  # Indonesian (Indonesia), Female
    'id-ID-ArdiNeural': 'id-ID',  # Indonesian (Indonesia), Male
    'ga-IE-OrlaNeural': 'ga-IE',  # Irish (Ireland), Female
    'ga-IE-ColmNeural': 'ga-IE',  # Irish (Ireland), Male
    'it-IT-ElsaNeural': 'it-IT',  # Italian (Italy), Female
    'it-IT-IsabellaNeural': 'it-IT',  # Italian (Italy), Female
    'it-IT-DiegoNeural': 'it-IT',  # Italian (Italy), Male
    'ja-JP-NanamiNeural': 'ja-JP',  # Japanese (Japan), Female
    'ja-JP-KeitaNeural': 'ja-JP',  # Japanese (Japan), Male
    'jv-ID-SitiNeural': 'jv-ID',  # Javanese (Indonesia), Female
    'jv-ID-DimasNeural': 'jv-ID',  # Javanese (Indonesia), Male
    'km-KH-SreymomNeural': 'km-KH',  # Khmer (Cambodia), Female
    'km-KH-PisethNeural': 'km-KH',  # Khmer (Cambodia), Male
    'ko-KR-SunHiNeural': 'ko-KR',  # Korean (Korea), Female
    'ko-KR-InJoonNeural': 'ko-KR',  # Korean (Korea), Male
    'lv-LV-EveritaNeural': 'lv-LV',  # Latvian (Latvia), Female
    'lv-LV-NilsNeural': 'lv-LV',  # Latvian (Latvia), Male
    'lt-LT-OnaNeural': 'lt-LT',  # Lithuanian (Lithuania), Female
    'lt-LT-LeonasNeural': 'lt-LT',  # Lithuanian (Lithuania), Male
    'ms-MY-YasminNeural': 'ms-MY',  # Malay (Malaysia), Female
    'ms-MY-OsmanNeural': 'ms-MY',  # Malay (Malaysia), Male
    'mt-MT-GraceNeural': 'mt-MT',  # Maltese (Malta), Female
    'mt-MT-JosephNeural': 'mt-MT',  # Maltese (Malta), Male
    'mr-IN-AarohiNeural': 'mr-IN',  # Marathi (India), Female
    'mr-IN-ManoharNeural': 'mr-IN',  # Marathi (India), Male
    'nb-NO-IselinNeural': 'nb-NO',  # Norwegian (Bokml, Norway), Female
    'nb-NO-PernilleNeural': 'nb-NO',  # Norwegian (Bokml, Norway), Female
    'nb-NO-FinnNeural': 'nb-NO',  # Norwegian (Bokml, Norway), Male
    'fa-IR-DilaraNeural': 'fa-IR',  # Persian (Iran), Female
    'fa-IR-FaridNeural': 'fa-IR',  # Persian (Iran), Male
    'pl-PL-AgnieszkaNeural': 'pl-PL',  # Polish (Poland), Female
    'pl-PL-ZofiaNeural': 'pl-PL',  # Polish (Poland), Female
    'pl-PL-MarekNeural': 'pl-PL',  # Polish (Poland), Male
    'pt-BR-FranciscaNeural': 'pt-BR',  # Portuguese (Brazil), Female
    'pt-BR-AntonioNeural': 'pt-BR',  # Portuguese (Brazil), Male
    'pt-PT-FernandaNeural': 'pt-PT',  # Portuguese (Portugal), Female
    'pt-PT-RaquelNeural': 'pt-PT',  # Portuguese (Portugal), Female
    'pt-PT-DuarteNeural': 'pt-PT',  # Portuguese (Portugal), Male
    'ro-RO-AlinaNeural': 'ro-RO',  # Romanian (Romania), Female
    'ro-RO-EmilNeural': 'ro-RO',  # Romanian (Romania), Male
    'ru-RU-DariyaNeural': 'ru-RU',  # Russian (Russia), Female
    'ru-RU-SvetlanaNeural': 'ru-RU',  # Russian (Russia), Female
    'ru-RU-DmitryNeural': 'ru-RU',  # Russian (Russia), Male
    'sk-SK-ViktoriaNeural': 'sk-SK',  # Slovak (Slovakia), Female
    'sk-SK-LukasNeural': 'sk-SK',  # Slovak (Slovakia), Male
    'sl-SI-PetraNeural': 'sl-SI',  # Slovenian (Slovenia), Female
    'sl-SI-RokNeural': 'sl-SI',  # Slovenian (Slovenia), Male
    'so-SO-UbaxNeural': 'so-SO',  # Somali (Somalia), Female
    'so-SO-MuuseNeural': 'so-SO',  # Somali (Somalia), Male
    'es-AR-ElenaNeural': 'es-AR',  # Spanish (Argentina), Female
    'es-AR-TomasNeural': 'es-AR',  # Spanish (Argentina), Male
    'es-BO-SofiaNeural': 'es-BO',  # Spanish (Bolivia), Female
    'es-BO-MarceloNeural': 'es-BO',  # Spanish (Bolivia), Male
    'es-CL-CatalinaNeural': 'es-CL',  # Spanish (Chile), Female
    'es-CL-LorenzoNeural': 'es-CL',  # Spanish (Chile), Male
    'es-CO-SalomeNeural': 'es-CO',  # Spanish (Colombia), Female
    'es-CO-GonzaloNeural': 'es-CO',  # Spanish (Colombia), Male
    'es-CR-MariaNeural': 'es-CR',  # Spanish (Costa Rica), Female
    'es-CR-JuanNeural': 'es-CR',  # Spanish (Costa Rica), Male
    'es-CU-BelkysNeural': 'es-CU',  # Spanish (Cuba), Female
    'es-CU-ManuelNeural': 'es-CU',  # Spanish (Cuba), Male
    'es-DO-RamonaNeural': 'es-DO',  # Spanish (Dominican Republic), Female
    'es-DO-EmilioNeural': 'es-DO',  # Spanish (Dominican Republic), Male
    'es-EC-AndreaNeural': 'es-EC',  # Spanish (Ecuador), Female
    'es-EC-LuisNeural': 'es-EC',  # Spanish (Ecuador), Male
    'es-SV-LorenaNeural': 'es-SV',  # Spanish (El Salvador), Female
    'es-SV-RodrigoNeural': 'es-SV',  # Spanish (El Salvador), Male
    'es-GQ-TeresaNeural': 'es-GQ',  # Spanish (Equatorial Guinea), Female
    'es-GQ-JavierNeural': 'es-GQ',  # Spanish (Equatorial Guinea), Male
    'es-GT-MartaNeural': 'es-GT',  # Spanish (Guatemala), Female
    'es-GT-AndresNeural': 'es-GT',  # Spanish (Guatemala), Male
    'es-HN-KarlaNeural': 'es-HN',  # Spanish (Honduras), Female
    'es-HN-CarlosNeural': 'es-HN',  # Spanish (Honduras), Male
    'es-MX-DaliaNeural': 'es-MX',  # Spanish (Mexico), Female
    'es-MX-JorgeNeural': 'es-MX',  # Spanish (Mexico), Male
    'es-NI-YolandaNeural': 'es-NI',  # Spanish (Nicaragua), Female
    'es-NI-FedericoNeural': 'es-NI',  # Spanish (Nicaragua), Male
    'es-PA-MargaritaNeural': 'es-PA',  # Spanish (Panama), Female
    'es-PA-RobertoNeural': 'es-PA',  # Spanish (Panama), Male
    'es-PY-TaniaNeural': 'es-PY',  # Spanish (Paraguay), Female
    'es-PY-MarioNeural': 'es-PY',  # Spanish (Paraguay), Male
    'es-PE-CamilaNeural': 'es-PE',  # Spanish (Peru), Female
    'es-PE-AlexNeural': 'es-PE',  # Spanish (Peru), Male
    'es-PR-KarinaNeural': 'es-PR',  # Spanish (Puerto Rico), Female
    'es-PR-VictorNeural': 'es-PR',  # Spanish (Puerto Rico), Male
    'es-ES-ElviraNeural': 'es-ES',  # Spanish (Spain), Female
    'es-ES-AlvaroNeural': 'es-ES',  # Spanish (Spain), Male
    'es-UY-ValentinaNeural': 'es-UY',  # Spanish (Uruguay), Female
    'es-UY-MateoNeural': 'es-UY',  # Spanish (Uruguay), Male
    'es-US-PalomaNeural': 'es-US',  # Spanish (US), Female
    'es-US-AlonsoNeural': 'es-US',  # Spanish (US), Male
    'es-VE-PaolaNeural': 'es-VE',  # Spanish (Venezuela), Female
    'es-VE-SebastianNeural': 'es-VE',  # Spanish (Venezuela), Male
    'su-ID-TutiNeural': 'su-ID',  # Sundanese (Indonesia), Female
    'su-ID-JajangNeural': 'su-ID',  # Sundanese (Indonesia), Male
    'sw-KE-ZuriNeural': 'sw-KE',  # Swahili (Kenya), Female
    'sw-KE-RafikiNeural': 'sw-KE',  # Swahili (Kenya), Male
    'sw-TZ-RehemaNeural': 'sw-TZ',  # Swahili (Tanzania), Female
    'sw-TZ-DaudiNeural': 'sw-TZ',  # Swahili (Tanzania), Male
    'sv-SE-HilleviNeural': 'sv-SE',  # Swedish (Sweden), Female
    'sv-SE-SofieNeural': 'sv-SE',  # Swedish (Sweden), Female
    'sv-SE-MattiasNeural': 'sv-SE',  # Swedish (Sweden), Male
    'ta-IN-PallaviNeural': 'ta-IN',  # Tamil (India), Female
    'ta-IN-ValluvarNeural': 'ta-IN',  # Tamil (India), Male
    'ta-SG-VenbaNeural': 'ta-SG',  # Tamil (Singapore), Female
    'ta-SG-AnbuNeural': 'ta-SG',  # Tamil (Singapore), Male
    'ta-LK-SaranyaNeural': 'ta-LK',  # Tamil (Sri Lanka), Female
    'ta-LK-KumarNeural': 'ta-LK',  # Tamil (Sri Lanka), Male
    'te-IN-ShrutiNeural': 'te-IN',  # Telugu (India), Female
    'te-IN-MohanNeural': 'te-IN',  # Telugu (India), Male
    'th-TH-AcharaNeural': 'th-TH',  # Thai (Thailand), Female
    'th-TH-PremwadeeNeural': 'th-TH',  # Thai (Thailand), Female
    'th-TH-NiwatNeural': 'th-TH',  # Thai (Thailand), Male
    'tr-TR-EmelNeural': 'tr-TR',  # Turkish (Turkey), Female
    'tr-TR-AhmetNeural': 'tr-TR',  # Turkish (Turkey), Male
    'uk-UA-PolinaNeural': 'uk-UA',  # Ukrainian (Ukraine), Female
    'uk-UA-OstapNeural': 'uk-UA',  # Ukrainian (Ukraine), Male
    'ur-IN-GulNeural': 'ur-IN',  # Urdu (India), Female
    'ur-IN-SalmanNeural': 'ur-IN',  # Urdu (India), Male
    'ur-PK-UzmaNeural': 'ur-PK',  # Urdu (Pakistan), Female
    'ur-PK-AsadNeural': 'ur-PK',  # Urdu (Pakistan), Male
    'uz-UZ-MadinaNeural': 'uz-UZ',  # Uzbek (Uzbekistan), Female
    'uz-UZ-SardorNeural': 'uz-UZ',  # Uzbek (Uzbekistan), Male
    'vi-VN-HoaiMyNeural': 'vi-VN',  # Vietnamese (Vietnam), Female
    'vi-VN-NamMinhNeural': 'vi-VN',  # Vietnamese (Vietnam), Male
    'cy-GB-NiaNeural': 'cy-GB',  # Welsh (United Kingdom), Female
    'cy-GB-AledNeural': 'cy-GB',  # Welsh (United Kingdom), Male
    'zu-ZA-ThandoNeural': 'zu-ZA',  # Zulu (South Africa), Female
    'zu-ZA-ThembaNeural': 'zu-ZA',  # Zulu (South Africa), Male
}
